<?php
/**
 * The front page template file
 *
 * If the user has selected a static page for their homepage, this is what will
 * appear.
 * Learn more: https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Biuro
 * @since 1.0
 * @version 1.0
 */

    get_header();
?>

<div class="l-section l-section--front-page">
    <div class="l-section--inner">
<?php
        while ( have_posts() ) :
?>
        <div class="c-heading c-heading--front-page">
<?php
            the_post();
            the_content();
?>
        </div>
<?php
        endwhile;
        get_search_form();
?>
    </div>
</div>

<div id="content">
    <main id="main" class="l-main">

        <div class="c-jobs">
            <div class="c-jobs--inner">

                <h2 class="c-jobs--headline"><?php _e('Recent job ads', 'biuro'); ?></h2>
<?php

            $where = 'valid.meta_value > "' . date('Y-m-d', strtotime('-1 days')) . '"';

            // WP Pods fix for multisite
            global $wpdb;
            global $biuroSettings;

            $params = array(
                'orderby' => 'date DESC',
                'where' => $where,
                'limit'   => $biuroSettings->field('workis_ad') ? 4 : 5
            );

            // if (get_current_blog_id() != 1):
            $langs = pll_the_languages(array('raw'=>1));
            $langID = $langs[pll_current_language('slug')]['id'];
            $where = $where . ' AND ( `langs`.`object_id` IS NOT NULL )';

            $params['join'] = ' LEFT JOIN `' . $wpdb->prefix . 'term_relationships` AS `langs` ON `langs`.`object_id` = `t`.`ID` AND `langs`.`term_taxonomy_id` = ' . $langID;
            $params['where'] = $where;
            // endif;
            // END WP Pods fix for multisite

            $jobs = pods( 'job', $params );

            if ( 0 < $jobs->total() ):

                if ($biuroSettings->field('workis_ad')):
                    get_template_part( 'template-parts/jobs/jobs', 'list-homepage' );
                else:
                    get_template_part( 'template-parts/jobs/jobs', 'list' );
                endif;

            else:
                get_template_part( 'template-parts/jobs/jobs', 'none' );
            endif;

            global $positionsPage;

            if ($positionsPage && 0 < $jobs->total()):
?>
                <div class="c-jobs--more">
                    <a href="<?php echo $positionsPage; ?>" class="o-btn c-btn--alt"><?php _e('More job ads', 'biuro'); ?></a>
                </div>
<?php
            endif;
?>
            </div>
        </div><!-- .c-jobs -->

<?php
            include 'template-parts/trust.php';
?>

<?php
            if ( is_active_sidebar( 'front_page_feedbacks' ) ) :
                dynamic_sidebar( 'front_page_feedbacks' );
            endif;
?>

<?php
            if ( is_active_sidebar( 'front_page_values' ) ) :
                dynamic_sidebar( 'front_page_values' );
            endif;
?>

        <div class="c-contact">
            <div class="c-contact--inner">

                <div class="c-contact--content">
                <?php
                    if ( is_active_sidebar( 'front_page_employees' ) ) :
                        dynamic_sidebar( 'front_page_employees' );
                    endif;
                 ?>
                    <div class="c-contact--img">
                        <picture>
                            <source srcset="/wp-content/themes/biuro/i/contact.webp" type="image/webp">
                            <img loading="lazy" src="/wp-content/themes/biuro/i/contact.png" alt="" width="328" height="95">
                        </picture>
                    </div>
                </div>

                <div class="c-contact--form">
        <?php
                        echo do_shortcode('[biuro-contacts--employees]');
        ?>
                </div>

            </div>
        </div><!-- .c-contact -->

        <div class="c-newsletter">
            <div class="c-newsletter--inner">

                <div class="c-newsletter--img">
                    <picture>
                        <source type="image/webp" media="(max-width: 959px)" srcset="/wp-content/themes/biuro/i/newsletter/newsletter-sm.webp">
                        <source type="image/webp" srcset="/wp-content/themes/biuro/i/newsletter/newsletter.webp">
                        <source  media="(max-width: 959px)" srcset="/wp-content/themes/biuro/i/newsletter/newsletter-sm.png">
                        <img loading="lazy" src="/wp-content/themes/biuro/i/newsletter/newsletter.png" alt="" width="278" height="345">
                    </picture>
                    <svg xmlns="http://www.w3.org/2000/svg" width="95px" height="95px" viewBox="0 0 95 95" class="c-newsletter--ico">
                        <path fill="#FFFFFF" d="M91.769,30.525L66.673,10.365C62.572,7.086,55.56,0,47.5,0 c-7.735,0-14.473,6.516-18.72,9.997l-0.453,0.367C23.788,13.973,4.007,29.883,3.25,30.505C1.456,31.98,0,35.063,0,37.385v48.709 C0,91.012,3.987,95,8.906,95h77.188C91.013,95,95,91.012,95,86.094V37.389C95,35.075,93.552,32,91.769,30.525z M86,84.889 C86,85.502,85.502,86,84.889,86H10.111C9.498,86,9,85.502,9,84.889v-46.95c0-0.335,0.151-0.653,0.412-0.864l24.5-19.674 C37.274,14.716,43.131,9,47.5,9c4.294,0,10.092,5.567,13.381,8.235l14.762,11.839c4.544,3.653,8.645,6.955,9.945,8.006 c0.199,0.161,0.365,0.477,0.403,0.749L86,37.943V84.889z M80.495,49.352c0.784,0.98,0.64,2.431-0.322,3.227L67.077,63.385 C62.887,66.833,55.976,74,48,74c-7.881,0-14.762-7.014-18.861-10.435L15.828,52.579l0,0c-0.962-0.796-1.106-2.247-0.322-3.227 l2.817-3.521c0.771-0.964,2.152-1.11,3.098-0.328l13.027,10.75c3.241,2.664,9.179,8.625,13.553,8.625 c4.172,0,9.705-5.379,13.112-8.257L74.58,45.503l0,0c0.946-0.782,2.327-0.636,3.098,0.328L80.495,49.352z"/>
                    </svg>
                </div>

                <div class="c-newsletter--content">
                    <h2 class="c-newsletter--headline"><?php _e('Get news from the labor market and get the latest offers!', 'biuro'); ?></h2>
                    <form name="form-newsletter" class="c-newsletter--form" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post">
                        <div class="c-newsletter--label">
                            <label for="newsletter-email" class="visually-hidden"><?php _e('Your email address', 'biuro'); ?></label>
                            <input id="newsletter-email" type="email" name="email" required placeholder="<?php _e('Your email address', 'biuro'); ?>" class="c-newsletter--input" />
                        </div>
                        <button type="submit" class="o-btn c-btn--main c-btn--newsletter"><?php _e('Subscribe', 'biuro'); ?></button>

                        <input type="hidden" name="action" value="newsletters_post">
                        <?php wp_nonce_field('newsletters_post_nonce', '_wpnonce_newsletters'); ?>
                    </form>
                    <div class="c-newsletter--privacy"><?php _e('We process your personal data to send you newsletters. More information at <a href="https://biuro.eu/privacy-en.html" target="_blank" rel="noopener">Personal Data Protection Policy.</a>', 'biuro'); ?></div>
                </div>


            </div>
        </div><!-- .c-newsletter -->

<?php
    if (isset($_SESSION['newsletters']) && $_SESSION['newsletters'] == 'subscribed'):
?>
        <div class="c-modal">
            <div class="c-modal--inner">
                <svg width="67px" height="67px">
                    <use href="#ico--success"></use>
                </svg>
                <p><?php _e('Thank you! You have successfully subscribed for newsletters.', 'biuro'); ?></p>
                <p><button  class="js-modal--close o-btn c-btn--main"><?php _e('OK', 'biuro'); ?></button></p>
            </div>
        </div>
        <script>
        window.dataLayer = window.dataLayer || [];
        window.dataLayer.push({ 'event': 'b2c_newsletters_subscribed', 'label': 'Front page' });
        </script>
<?php
        unset($_SESSION['newsletters']);
    endif;
?>

    </main><!-- .l-main -->
</div><!-- #content -->

<?php get_footer();
