// https://github.com/webpack/webpack/issues/8656#issuecomment-456001556

// import "core-js/es";

import './polyfills/polyfills';

import { inititateRecaptcha } from './core/';

import { getAccordion, getFeedbackSwiper, getAutocomplete, getMaps, getJobShare, inititatePopup, getTabs } from './components/components';

if (module.hot) {
    module.hot.accept();
}

(global => {
    const container = document.getElementById('cookie-warning');
    const btnAgree = document.getElementById('cookie-agree');
    const btnClose = document.getElementById('cookie-close');
    const agreed = (useLS()) ? localStorage.getItem('biuro-agree') : false;

    function useLS () {
        var mod = 'a';
        try {
            localStorage.setItem(mod, mod);
            localStorage.removeItem(mod);
            return true;
        } catch (e) {
            return false;
        }
    }

    if (!container || !btnAgree || !btnClose || agreed) {
        return;
    }

    container.style.display = 'block';

    btnAgree.addEventListener('click', () => {
        if (useLS()) {
            localStorage.setItem('biuro-agree', 'true');
        }
        container.style.display = 'none';
    });

    btnClose.addEventListener('click', () => {
        container.style.display = 'none';
    });
})(window);

(global => {
    const node = document.querySelector('.c-nav--lang');

    if (!node) {
        return;
    }

    node.addEventListener('click', (e) => {
        e.currentTarget.classList.toggle('c-nav--lang--is-open');
    });
})(window);

(global => {
    document.querySelectorAll('.js-toggle--nav').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.toggle('is-nav--open');
        });
    });

    document.querySelectorAll('.js-toggle--aside').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.remove('is-aside--open');
            document.body.classList.remove('is-aside--open-additional');
            document.body.classList.remove('is-aside--open-city');
        });
    });

    document.querySelectorAll('.js-toggle--aside-city').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.add('is-aside--open');
            document.body.classList.remove('is-aside--open-additional');
            document.body.classList.add('is-aside--open-city');
        });
    });

    document.querySelectorAll('.js-toggle--aside--additional').forEach((node) => {
        node.addEventListener('click', (e) => {
            e.preventDefault();
            document.body.classList.toggle('is-aside--open');
            document.body.classList.remove('is-aside--open-city');
            document.body.classList.add('is-aside--open-additional');
        });
    });
})(window);

document.querySelectorAll('.js-form--input-file').forEach((node) => {
    node.addEventListener('change', () => {
        const parent = node.parentNode;
        const name = node.value.split(/\\|\//).pop();
        const text = parent.querySelector('.js-form--input-file-text');

        if (text && name) {
            text.innerHTML = name;
        }
    });
});

document.querySelectorAll('.js-toggle--services').forEach((node) => {
    node.addEventListener('click', () => {
        node.parentNode.classList.toggle('c-services--is-open');
    });
});

document.querySelectorAll('.js-toggle--sections').forEach((node) => {
    node.addEventListener('click', () => {
        const parent = node.parentNode;

        if (parent.classList.contains('c-sections--is-open')) {
            parent.classList.toggle('c-sections--is-open');
        } else {
            document.querySelectorAll('.c-sections--is-open').forEach((node) => {
                node.classList.remove('c-sections--is-open');
            });
            parent.classList.toggle('c-sections--is-open');
        }
    });
});

document.querySelectorAll('.js-expand-jobs-section').forEach((node) => {
    node.addEventListener('click', (e) => {
        e.preventDefault();
        node.parentNode.classList.remove('c-jobs-section--is-closed');
        node.remove();
    });
});

const initiatePositionForm = () => {
    const button = document.querySelector('[name="s"][value="1"]');

    if (button) {
        button.click();
        return;
    }

    const input = document.querySelector('[name="name"]');

    if (input) {
        input.focus();
    }
};

if (document.querySelector('.js-inititate-position-form')) {
    document.querySelector('.js-inititate-position-form').addEventListener('click', initiatePositionForm);
}

if (document.querySelector('.js-focus-form')) {
    document.querySelector('.js-focus-form').addEventListener('click', () => {
        const input = document.querySelector('.c-form input:first-of-type');

        if (input) {
            input.focus();
        }
    });
}

if (document.querySelector('.js-modal--close')) {
    document.querySelector('.js-modal--close').addEventListener('click', () => {
        const modal = document.querySelector('.c-modal');

        if (modal) {
            modal.remove();
        }

        const node = document.querySelector('.c-form [autofocus]');

        if (node) {
            node.focus();
        }
    });
}

(global => {
    const node = document.querySelector('.c-form [autofocus]');

    if (node) {
        node.focus();
    }

    if (location.hash) {
        const error = document.querySelector('.c-form--input-wrap--error input') || document.querySelector('.c-form--checkbox--error');

        if (error) {
            error.focus();
            return;
        }

        const input = document.querySelector('.c-form [name="name"]');

        if (input) {
            input.focus();
        }
    }
})(window);

(global => {
    window.dataLayer = window.dataLayer || [];

    const getJobID = () => {
        const jobID = (document.querySelector('input[name="job_id"]') || {}).value;

        return jobID ? parseInt(jobID) : '';
    }

    const getCategory = () => {
        const node = document.querySelector('meta[itemprop="occupationalCategory"]');

        if (!node) {
            return '';
        }

        return node.getAttribute('content') || '';
    }

    document.querySelectorAll('.gtm-share-click').forEach((node) => {
        node.addEventListener('click', (e) => {
            const dataset = node.dataset || {};
            window.dataLayer.push({
                event: 'shareClick',
                shareLabel: dataset.label || ''
            });
        });
    });

    document.querySelectorAll('.gtm-click').forEach((node) => {
        node.addEventListener('click', (e) => {
            const dataset = node.dataset || {};
            window.dataLayer.push({
                event: dataset.event || '',
                label: dataset.label || ''
            });
        });
    });

    const storage = window.sessionStorage;
    const opened = document.querySelector('[name="gtm-position-opened"]');
    const started = document.querySelector('[name="gtm-application-started"]');
    const submitted = document.querySelector('[name="gtm-application-submitted"]');

    const jobID = getJobID();

    const setPositionOpened = () => {
        window.dataLayer.push({ 'event': 'offerOpened', 'job_id': jobID, 'category': getCategory()});
        storage.setItem(`position-${jobID}`, 'opened');
    };

    const setApplicationStarted = () => {
        window.dataLayer.push({ 'event': 'applicationStarted', 'job_id': jobID, 'category': getCategory()});
        storage.setItem(`position-${jobID}`, 'started');
    };

    const setApplicationSubmitted = () => {
        window.dataLayer.push({ 'event': 'applicationSuccess', 'job_id': jobID, 'category': getCategory()});
        storage.setItem(`position-${jobID}`, 'submitted');
    };

    const handleInputChange = (e) => {
        if (e.target.value) {
            setApplicationStarted();
            e.target.removeEventListener('input', handleInputChange)
        }
    };

    if (opened) {
        if (!storage.getItem(`position-${jobID}`)) {
            setPositionOpened();
        }
    }

    if (started && storage.getItem(`position-${jobID}`) === 'opened') {
        const node = document.querySelector('[name="form-position"] #form-name') || {};

        if (node) {
            if (node.value) {
                setApplicationStarted();
            } else {
                node.addEventListener('input', handleInputChange)
            }
        }
    }

    if (submitted && storage.getItem(`position-${jobID}`) === 'started') {
        setApplicationSubmitted();
    }
})(window);

const submitContactsFrom = (form) => {
    if (form.querySelector('[type="submit"]')) {
        form.querySelector('[type="submit"]').classList.add('c-btn--disabled');
        form.querySelector('[type="submit"]').classList.add('c-btn--loading');
    }
};

document.querySelectorAll('[name="form-position"], [name="form-employees"], [name="form-employers"], [name="form-recommend"], [name="form-newsletter"]').forEach((form) => {
    form.addEventListener('submit', () => { submitContactsFrom(form); });
});

if (document.querySelector('#submit-recommend')) {
    document.querySelector('#submit-recommend').addEventListener('click', (e) => {
        e.preventDefault();

        const button = document.querySelector('[name="form-recommend"] [type="submit"]');

        if (!button) {
            return;
        }

        e.currentTarget.classList.add('c-btn--disabled');
        e.currentTarget.classList.add('c-btn--loading');

        button.click();
    });
}

if (document.querySelector('.js-submit-employees-form')) {
    document.querySelector('.js-submit-employees-form').addEventListener('click', (e) => {
        const button = document.querySelector('[name="form-employees"] [type="submit"]');

        if (!button) {
            return;
        }

        e.preventDefault();

        e.currentTarget.classList.add('c-btn--disabled');
        e.currentTarget.classList.add('c-btn--loading');

        button.click();
    });
}

if (document.querySelector('.js-accordion--header')) {
    getAccordion().then(inititateAccordion => {
        inititateAccordion();
    });
}

if (document.querySelector('.js-tabs')) {
    getTabs().then(inititateTabs => {
        inititateTabs();
    });
}

const inititateFeedbacks = (node) => {
    if (!node) {
        return;
    }

    const inititate = () => {
        getFeedbackSwiper().then(inititateFeedbackSwiper => {
            inititateFeedbackSwiper();
        });
    };

    if (!window.IntersectionObserver) {
        inititate();
        return;
    }

    const io = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                inititate();
                io.unobserve(entry.target);
            }
        });
    }, {});

    io.observe(node);
};

inititateFeedbacks(document.querySelector('.c-feedbacks--inner'));

const inititateAutocompletes = () => {
    const inititate = () => {
        getAutocomplete().then(inititateAutocomplete => {
            inititateAutocomplete();
        });
    };

    if (window.requestIdleCallback) {
        window.requestIdleCallback(inititate);
    } else {
        inititate();
    }
};

if (document.getElementById('search') || document.getElementById('form-city') || document.getElementById('recommend-form-city')) {
    inititateAutocompletes();
}

if (document.getElementById('js-map--divisions') || document.getElementById('js-map--cities') || document.getElementById('js-map--regions')) {
    getMaps().then(inititateMap => {
        inititateMap();
    });
}

if (document.querySelector('.js-copy-to-clipboard') || document.querySelector('.js-share-messenger') || document.querySelector('.js-share-whatsapp') || document.querySelector('.js-biuro-facebook')) {
    getJobShare().then(inititateJobShare => {
        inititateJobShare();
    });
}

inititatePopup();

if (document.querySelector('.js-collapse-row--toggle')) {
    document.querySelector('.js-collapse-row--toggle').addEventListener('click', (e) => {
        e.currentTarget.parentNode.classList.toggle('c-form--row--collapsed');
    });
}

const recaptcha = document.getElementById('g-recaptcha-response');

if (recaptcha) {
    inititateRecaptcha(recaptcha);
}

(global => {
    const form = document.getElementById('search');

    if (!form) {
        return;
    }

    document.querySelectorAll('.js-search--focus').forEach((node) => {
        node.addEventListener('focus', () => {
            if (window.innerWidth < 960 && form.getBoundingClientRect().top > 80) {
                window.scroll(0, 210);
            }
        });
    });
})(window);

(global => {
    const hiddenCSS = 'is-header--hidden';
    const header = document.querySelector('.l-header');
    const delay = 250;

    if (!header) {
        return true;
    }

    let dHeight = 0;
    let wHeight = 0;
    let wScrollCurrent = 0;
    let wScrollBefore = 0;
    let wScrollDiff = 0;

    const throttle = function (delay, fn) {
        var last, deferTimer;

        return function () {
            const context = this;
            const args = arguments;
            const now = new Date();

            if (last && now < last + delay) {
                clearTimeout(deferTimer);
                deferTimer = setTimeout(() => { last = now; fn.apply(context, args); }, delay);
            } else {
                last = now;
                fn.apply(context, args);
            }
        };
    };

    window.addEventListener('scroll', throttle(delay, function () {
        dHeight = document.body.offsetHeight;
        wHeight = window.innerHeight;
        wScrollCurrent = window.pageYOffset;
        wScrollDiff = wScrollBefore - wScrollCurrent;

        if (wScrollCurrent <= 0) {
            header.classList.remove(hiddenCSS);
        } else if (wScrollDiff > 0 && header.classList.contains(hiddenCSS)) {
            header.classList.remove(hiddenCSS);
        } else if (wScrollDiff < 0) {
            if (wScrollCurrent + wHeight >= dHeight && header.classList.contains(hiddenCSS)) {
                header.classList.remove(hiddenCSS);
            } else if (!document.body.classList.contains('is-nav--open')) {
                header.classList.add(hiddenCSS);
            }
        }

        wScrollBefore = wScrollCurrent;
    }));
})(window);
